---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:1999-04-21;116
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=19990429&codiceRedaz=099G0189&dataVigenza=20251104
dataGU: 19990429
codiceRedaz: 099G0189
dataVigenza: 20251104
---

# Riordino dell'Istituto Poligrafico e Zecca dello Stato ai fini della sua trasformazione in societa' per azioni, a norma degli articoli 11 e 14 della legge 15 marzo 1997, n. 59.

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76 e 87 della Costituzione;

Vista la legge 13 luglio 1966, n. 559, e successive modifiche ed integrazioni, recante nuovo ordinamento dell'Istituto Poligrafico dello Stato;

Visti, in particolare, gli articoli 11, comma 1, lettera b), e 14, comma 1, lettera b), della legge 15 marzo 1997, n. 59, e successive modifiche ed integrazioni, che hanno conferito al Governo la delega a riordinare gli enti pubblici nazionali operanti in settori diversi dall'assistenza e previdenza, anche mediante trasformazione in ente pubblico economico o in societa' di diritto privato di enti ad alto indice di autonomia finanziaria;

Visto l'articolo 55, comma 3, della legge 27 dicembre 1997, n. 449;

Visto l'articolo 9, comma 6, della legge 8 marzo 1999, n. 50;

Vista la preliminare deliberazione del Consiglio dei Ministri, adottata nella riunione del 27 novembre 1998;

Acquisito il parere della commissione bicamerale istituita ai sensi dell'articolo 5 della citata legge n. 59 del 1997;

Vista la deliberazione del Consiglio dei Ministri, adottata nella riunione del 31 marzo 1999;

Sulla proposta del Presidente del Consiglio dei Ministri e del Ministro del tesoro, del bilancio e della programmazione economica, di concerto con i Ministri per la funzione pubblica e delle finanze;

Emana il seguente decreto legislativo:

## Art. 1.

1. L'articolo 1 della legge 13 luglio 1966, n. 559, e successive modifiche ed integrazioni, e' sostituito dal seguente: "Art. 1. - 1. L'Istituto Poligrafico e Zecca dello Stato, di seguito denominato anche Istituto, e' trasformato in societa' per azioni entro il 31 dicembre 2001, previa verifica dei necessari requisiti economici e patrimoniali e approvazione di un piano triennale d'impresa da parte del Ministro del tesoro, del bilancio e della programmazione economica, comprensivo del piano riguardante la gestione del patrimonio immobiliare. Le azioni della societa' derivante dalla trasformazione dell'Istituto sono attribuite al Tesoro dello Stato. 2. Sino alla trasformazione in societa' per azioni, l'Istituto conserva la personalita' giuridica di ente pubblico economico, e' sottoposto alla vigilanza del Ministro del tesoro, del bilancio e della programmazione economica ed e' disciplinato dalla presente legge.".

## Art. 2.

1. L'articolo 2 della legge 13 luglio 1966, n. 559, e successive modifiche ed integrazioni, e' sostituito dal seguente: "Art. 2. - 1. L'Istituto Poligrafico e Zecca dello Stato ha per compiti la produzione e la fornitura della carta, delle carte valori, degli stampati e delle pubblicazioni anche su supporti informatici, nonche' dei prodotti cartotecnici per il fabbisogno delle amministrazioni dello Stato. 2. L'Istituto provvede alla stampa ed alla gestione, anche con strumenti telematici, della Gazzetta Ufficiale e della Raccolta ufficiale degli atti normativi della Repubblica italiana, salva la competenza del Ministero di grazia e giustizia per quanto concerne la direzione e la redazione delle stesse, nonche' alla stampa delle pubblicazioni ufficiali dello Stato. 3. L'Istituto cura la stampa di pubblicazioni di carattere legislativo, di raccolte e di estratti di leggi e atti ufficiali e di pubblicazioni similari. 4. L'Istituto puo', inoltre, pubblicare e vendere opere aventi rilevante carattere artistico, letterario, scientifico e, in genere, culturale, ferme restando in materia le attribuzioni del Ministero per i beni e le attivita' culturali. 5. L'Istituto svolge, altresi', i seguenti compiti: a) conio delle monete di Stato in conformita' delle leggi vigenti; b) conio di monete estere; c) conio di monete a corso legale di speciale scelta da cedere, a norma di legge, a privati, enti ed associazioni; d) conio di medaglie e fusioni artistiche per conto dello Stato italiano, di Stati esteri, di enti e privati; e) fabbricazione di sigilli ufficiali e marchi metallici recanti l'emblema dello Stato; f) fabbricazione di timbri metallici e marchi per conto di enti pubblici e di privati; g) fabbricazione di contrassegni di Stato; h) fabbricazione di targhe, distintivi metallici, gettoni ed altri prodotti artistici; i) promozione dell'attivita' della Scuola dell'arte della medaglia e del Museo della Zecca; l) esecuzione di saggi su monete e metalli per conto dello Stato e di privati; m) riparazione di congegni e macchinari in uso o in proprieta' dello Stato; n) partecipazione a studi, rilevazioni e prove sperimentali nelle materie attinenti al campo specifico della meccanica; o) perizia delle monete ritenute false; p) conio di monete commemorative o celebrative; q) fabbricazione di contrassegni per macchine affrancatrici per conto dello Stato; r) promozione e partecipazione a studi, rilevazioni e prove sperimentali nelle materie attinenti alle funzioni di cui al presente articolo. 6. La coniazione da parte della sezione Zecca di monete per conto di Stati esteri dovra' essere preventivamente autorizzata dal Ministero del tesoro, del bilancio e della programmazione economica. 7. L'Istituto puo' vendere i suoi prodotti alle aziende autonome di Stato, ad enti e a privati italiani e stranieri ed assumere commesse in materia cartaria e, con l'autorizzazione del servizio centrale del Provveditorato generale dello Stato del Ministero del tesoro, del bilancio e della programmazione economica, in materia grafica. 8. Nello svolgimento della sua attivita', l'Istituto puo' esercitare, direttamente o indirettamente, attivita' affini, ausiliarie, connesse o strumentali rispetto a quelle previste nel presente articolo. 9. L'Istituto, nello svolgimento della sua attivita' puo' compiere ogni operazione di natura mobiliare o immobiliare necessaria od utile al raggiungimento delle sue finalita'. 10. Le attivita' e i compiti di cui al presente articolo sono svolti nel rispetto della normativa comunitaria in materia.".

## Art. 3.

1. L'articolo 8 della legge 13 luglio 1966, n. 559, e successive modifiche ed integrazioni, e' sostituito dal seguente: "Art. 8. - 1. Sono organi dell'Istituto: a) il presidente; b) il consiglio di amministrazione; c) il collegio dei revisori.".

## Art. 4.

1. L'articolo 9 della legge 13 luglio 1966, n. 559, e successive modifiche ed integrazioni, e' sostituito dal seguente: "Art. 9. - 1. Il presidente e' nominato, ai sensi dell'articolo 3 della legge 23 agosto 1988, n. 400, con decreto del Presidente della Repubblica emanato su proposta del Presidente del Consiglio dei Ministri, previa deliberazione del Consiglio dei Ministri adottata su proposta del Ministro del tesoro, del bilancio e della programmazione economica. Dura in carica un triennio e puo' essere confermato.".

## Art. 5.

1. L'articolo 10 della legge 13 luglio 1966, n. 559, e successive modifiche ed integrazioni, e' sostituito dal seguente: "Art. 10. - 1. Il consiglio di amministrazione dell'Istituto Poligrafico e Zecca dello Stato e' composto dal presidente dell'Istituto, che lo presiede, e da sei componenti nominati con decreto del Ministro del tesoro, del bilancio e della programmazione economica, scelti fra persone di elevata competenza e professionalita' nelle materie e nei settori di attivita' nei quali opera l'Istituto, assicurando tra l'altro la presenza di esperti nelle materie grafiche e cartarie, con esclusione dei soggetti che possano comunque trovarsi in situazione di conflitto di interessi. 2. Il consiglio di amministrazione dura in carica tre anni ed i suoi componenti possono essere confermati esclusivamente per un ulteriore triennio. Alla scadenza di ciascun triennio decadono anche i consiglieri eventualmente nominati, durante il periodo medesimo, in sostituzione di altri componenti. 3. Al consiglio di amministrazione partecipa, senza diritto di voto, il provveditore generale dello Stato che, in caso di impedimento, e' sostituito da un funzionario da lui incaricato. 4. Quando occorra deliberare in materia di cartevalori, al consiglio partecipa, a titolo consultivo, il capo del servizio ispettorato cartevalori del servizio centrale del Provveditorato generale dello Stato del Ministero del tesoro, del bilancio e della programmazione economica.".

## Art. 6.

1. L'articolo 12 della legge 13 luglio 1966, n. 559, e successive modifiche ed integrazioni, e' sostituito dal seguente: "Art. 12. - 1. Il collegio dei revisori e' nominato con decreto del Ministro del tesoro, del bilancio e della programmazione economica, dura in carica tre anni ed i suoi componenti possono essere confermati esclusivamente per un ulteriore triennio. 2. Il collegio e' composto di tre revisori effettivi e di tre supplenti, scelti tra gli iscritti nel registro dei revisori contabili istituito presso il Ministero di grazia e giustizia. 3. Il presidente ed il suo supplente sono scelti tra i dirigenti dello Stato con incarico dirigenziale generale presso il Ministero del tesoro, del bilancio e della programmazione economica.".

## Art. 7.

1. L'articolo 14 della legge 13 luglio 1966, n. 559, e successive modifiche ed integrazioni, e' sostituito dal seguente: "Art. 14. - 1. Il consiglio di amministrazione: a) delibera gli indirizzi generali e il programma annuale di attivita'; b) delibera i bilanci dell'Istituto; c) delibera il conferimento dell'incarico a societa' di revisione per la certificazione del bilancio di esercizio e del bilancio consolidato; d) formula gli indirizzi programmatici generali relativi alle societa' partecipate; e) delibera, in via generale, le linee organizzative dell'Istituto e gli indirizzi per la gestione delle risorse umane, ivi compresi i criteri per le assegnazioni e i trasferimenti del personale; f) delibera, su proposta del presidente, l'assunzione e le relative modalita', nonche' la risoluzione del rapporto di lavoro del direttore generale; g) delibera le modalita' di assunzione del personale, secondo criteri e procedure che garantiscano la trasparenza delle scelte e l'efficienza dei servizi; h) autorizza l'acquisto, l'alienazione e la permuta dei beni immobili, l'accensione di mutui e la costituzione di diritti reali sui beni di proprieta'; i) delibera l'assunzione di obbligazioni e la prestazione di ogni forma di garanzia; l) delibera l'utilizzo del fondo di riserva speciale di cui al quarto comma dell'articolo 22; m) autorizza le azioni giudiziarie e le transazioni; n) delibera, su proposta del presidente, nelle materie di cui agli articoli 2364 e 2365 del codice civile, la volonta' dell'Istituto da esprimersi nelle assemblee delle societa' nelle quali l'Istituto detiene direttamente partecipazioni superiori al venti per cento del capitale sociale; o) delibera sull'acquisto e sulla dismissione di partecipazioni; p) determina i limiti di somma entro i quali il presidente e il direttore generale autorizzano le spese. 2. Per le materie riguardanti la ''Sezione Zecca'', il consiglio di amministrazione puo' avvalersi della consulenza di un comitato composto dal direttore della ''Sezione Zecca'' e da due esperti designati dal consiglio medesimo all'inizio di ciascun anno. 3. Il consiglio di amministrazione, nei limiti di cui all'articolo 2381 del codice civile, puo' delegare proprie attribuzioni al presidente. 4. Dell'esercizio delle deleghe ad esso attribuite il presidente e' tenuto a riferire al consiglio di amministrazione, secondo le modalita' e nei tempi da questo stabiliti. 5. La deliberazione indicata alla lettera b) del comma 1 e' sottoposta all'approvazione del Ministro del tesoro, del bilancio e della programmazione economica, con le modalita' di cui all'articolo 23. Trascorsi novanta giorni dal ricevimento della predetta deliberazione da parte del Ministero vigilante, i bilanci si intendono approvati. Qualora siano formulate osservazioni, il termine e' interrotto e ricomincia a decorrere per intero, per una sola volta, a partire dalla data in cui le risposte dell'istituto pervengono allo stesso Ministero vigilante.".

2. Le attribuzioni di cui al comma 1, lettera g), dell'articolo 14 della legge 13 luglio 1966, n. 559, cosi' come sostituito dal comma 1, sono esercitate nel rispetto di quanto disposto dall'articolo 13, comma 2.

## Art. 8.

1. L'articolo 19 della legge 13 luglio 1966, n. 559, e successive modifiche ed integrazioni, e' sostituito dal seguente: "Art. 19. - 1. Fino alla trasformazione in societa' per azioni e' in facolta' dell'Istituto avvalersi dell'Avvocatura generale dello Stato per la difesa e la rappresentanza davanti a qualsiasi giurisdizione.".

## Art. 9.

1. Al primo comma dell'articolo 21 della legge 13 luglio 1966, n. 559, e successive modifiche ed integrazioni, sono aggiunte, in fine, le seguenti parole: "e ad ogni altra operazione necessaria per la sua trasformazione in societa' per azioni.".

2. Il terzo comma dell'articolo 21 della legge 13 luglio 1966, n. 559, e successive modifiche ed integrazioni, e' sostituito dal seguente: "Le domande di somministrazione dell'Istituto Poligrafico e Zecca dello Stato sono corredate: a) dall'autorizzazione al pagamento rilasciata dal servizio centrale del Provveditorato generale dello Stato del Ministero del tesoro, del bilancio e della programmazione economica sulla base dei piani di spesa, per l'acquisto di terreni, di macchinari e di altri beni strumentali, e degli stati di avanzamento dei lavori per le opere e gli impianti; b) dall'autorizzazione del Ministro del tesoro, del bilancio e della programmazione economica per ogni altra operazione necessaria per la trasformazione dell'Istituto in societa' per azioni.".

## Art. 10.

1. L'articolo 23 della legge 13 luglio 1966, n. 559, e successive modifiche ed integrazioni, e' sostituito dal seguente: "Art. 23. - 1. L'esercizio finanziario dell'Istituto ha inizio il 1 gennaio e termina il 31 dicembre di ciascun anno. 2. Entro il mese di giugno di ogni anno il consiglio di amministrazione presenta al Ministro del tesoro, del bilancio e della programmazione economica, per l'approvazione, il bilancio d'esercizio e il bilancio consolidato, redatti, rispettivamente, ai sensi degli articoli 2423 e seguenti del codice civile e del decreto legislativo 9 aprile 1991, n. 127, in quanto applicabili, accompagnati dalla relazione del collegio dei revisori dei conti. 3. Gli utili netti risultanti dal bilancio d'esercizio sono destinati ad una apposita riserva, utilizzabile in sede di trasformazione dell'Istituto in societa' per azioni.".

## Art. 11.

1. L'articolo 24 della legge 13 luglio 1966, n. 559, e successive modifiche ed integrazioni, e' abrogato.

2. Dalla data di entrata in vigore del presente decreto legislativo, i rapporti economici e giuridici dell'Istituto con i propri dipendenti sono disciplinati dai contratti collettivi nazionali di lavoro per i dirigenti di aziende industriali, per i dipendenti dalle aziende grafiche e per i dipendenti dalle aziende cartarie, ed eventuali trattamenti integrativi aziendali.

3. Allo scopo di agevolare il processo di trasformazione dell'Istituto in societa' per azioni, il Ministro del tesoro, del bilancio e della programmazione economica disciplina, con proprio decreto, criteri e modalita' per la formazione dei prezzi delle forniture, al fine di assicurarne la flessibilita' e di promuoverne l'adeguamento alla situazione del mercato.

4. Fino alla trasformazione in societa' per azioni dell'Istituto Poligrafico e Zecca dello Stato, il personale dipendente dell'Istituto puo' essere comandato presso le amministrazioni pubbliche di cui all'articolo 1, comma 2, del decreto legislativo 3 febbraio 1993, n. 29, e successive modifiche ed integrazioni.

5. In sede di trasformazione dell'Istituto in societa' per azioni le eventuali attivita' o produzioni da affidarsi in esclusiva, nel rispetto della normativa comunitaria, sono svolte con separazione contabile o societaria rispetto alle attivita' o alle produzioni dedicate al mercato.

6. Il presidente, il consiglio di amministrazione e il collegio dei revisori restano in carica, a far data dai rispettivi provvedimenti di nomina, per la durata dei rispettivi mandati stabilita dagli articoli 9, 10, comma 2, e 12 della legge 13 luglio 1966, n. 559, cosi' come sostituiti dal presente decreto. Il mandato cessa comunque in caso di trasformazione dell'Istituto in societa' per azioni.

7. Le disposizioni del presente decreto si applicano fino alla trasformazione dell'Istituto in societa' per azioni.

## Art. 12.

1. Sono abrogati l'articolo 6, comma 2, del decreto-legge 28 agosto 1995, n. 361, convertito, con modificazioni, dalla legge 27 ottobre 1995, n. 437, e gli articoli 11, 13, primo comma, lettere e) ed f), 15, 17, primo comma, 18, 25 e 26 della legge 13 luglio 1966, n. 559, e successive modifiche e integrazioni.

2. All'articolo 13, secondo comma, della legge 13 luglio 1966, n. 559, e successive modifiche e integrazioni, le parole: "del comitato esecutivo" sono sostituite dalle seguenti: "del consiglio di amministrazione.".

3. Sono inoltre abrogati gli articoli 2, 3 e 4 della legge 20 aprile 1978, n. 154.

## Art. 13.

1. Il presente decreto entra in vigore il giorno successivo a quello della sua pubblicazione nella Gazzetta Ufficiale della Repubblica italiana.

